@@ -48,5 +48,7 @@ class PBTConfig:
             cfg = orjson.loads(f.read())
 
         return PBTConfig(
-            cwd=cwd, ignore_packages=set(cfg["ignore_packages"]), cache_dir=cache_dir
+            cwd=cwd,
+            ignore_packages=set(cfg.get("ignore_packages", [])),
+            cache_dir=cache_dir,
         )
