@@ -24,7 +24,7 @@ DIFF_DB_CACHE = {}
 
 
 @contextmanager
-def diff_db(pkg: "Package", cfg: PBTConfig, new_connection: bool = True) -> rocksdb.DB:
+def diff_db(pkg: "Package", cfg: PBTConfig, new_connection: bool = False) -> rocksdb.DB:
     global DIFF_DB_CACHE
     db_file = str(cfg.cache_dir / f"{pkg.name}.db")
     if new_connection:
